@@ -51,7 +51,7 @@ class R3sponse(object):
 		return response
 	def error_response(self,
 		# the error message.
-		error, 
+		error="", 
 		# log log level of the message (int).
 		log_level=None, 
 		# save the error to the erros file.
@@ -66,6 +66,10 @@ class R3sponse(object):
 		if django: response = JsonResponse(response)
 		return response
 		#
+	def success(self, response):
+		if response["error"] == None:
+			return True
+		else: return False
 
 	# parameter functions.
 	def get_request_parameter(self, request, identifier):
